<?php

/*
 * @package RS-MINI
 * @copyright (c) 2015-2016 Alexey Glumov aka Rio-Shaman (support@rio-shaman.ru)
 * @license GNU General Public License version 2; see LICENSE.txt
 *
 */
 
namespace core;

if(!defined('RS-MINI')) die();

/*
 * sql v1.0
 * 
 * класс по работе с sql запросами
 *
 */

class sql
{
    /*
     * число рядов в результирующей выборке
     *
     * @var    - integer
     * @access - public
     */
     
    public $numRows = 0;

    /*
     * число строк, затронутых последним INSERT, UPDATE, REPLACE или DELETE запросом
     * > 0 все ОК. == -1 ошибка, или значение по умолчанию. == 0 запрос UPDATE ничего не обновил
     *
     * @var    - integer
     * @access - public
     */
     
    public $affectedRows = -1;

    /*
     * автоматически генерируемый ID, последнего запроса
     *
     * @var    - integer
     * @access - public
     */

    public $insertID = 0;

    /*
     * указатель на выборку
     *
     * @var    - integer
     * @access - private
     */
     
    private $resourceQuery = FALSE;

    /*
     * кол-во сделанных селект запросов
     *
     * @var    - integer
     * @access - public
     */
     
    public static $selectCount = 0;

    /*
     * указатель на соединение с MySQL
     *
     * @var    - resource
     * @access - private
     */
     
    private static $resource = FALSE;
    
    /*
     * подключаемся к БД
     * 
     * @access - public
     * 
     */
    
    public static function setConnect()
    {
        // подключаемся к БД
        self::$resource = @mysqli_connect(
            DB_SERVER, // сервер
            DB_USER,   // юзер
            DB_PASS,   // пароль юзера
            DB_NAME    // база данных
        );

        // если подключение прошло с ошибкой
        if (!self::$resource)
            die('Ошибка ' . CMS . ' v' . VERSION . ': При подключение к базе данных произошла ошибка');

        // устанавливаем кодировку базы
        mysqli_set_charset(self::$resource, "utf8");
    }

    /*
     * создание объекта и исполнение sql запроса
     * \core\sql::query('запрос')
     * 
     * @access - public
     * @return - объект sql класса
     *
     * @param sql - SQL запрос
     */
    
    public static function query($sql)
    {
        // поднимаем объект класса sql
        $obj = new sql();
        
        // исполняем запрос
        $obj->resourceQuery = mysqli_query(self::$resource, $sql);
        
        // наполняем данные
        // кол-во выбранных строк с помощью SELECT
        $obj->numRows       = @mysqli_num_rows($obj->resourceQuery);
        // кол-во затронутых строк последним INSERT, UPDATE, REPLACE или DELETE запросом
        $obj->affectedRows  = @mysqli_affected_rows(self::$resource);
        // автоматически генерируемый ID, последнего запроса
        $obj->insertID      = @mysqli_insert_id(self::$resource);
        
        // вертаем объект (для того что бы можно было
        // исполнить метод fetch(), или достучаться
        // до свойств с информацией)
        return $obj;
    }
    
    /*
     * метод получает выборку запроса
     * \core\sql::query('запрос')->fetch()
     * 
     * @access - public
     * @return - ассоциативный массив с выбранными строками
     *           из БД или FALSE если ничего небыло выбранно
     * 
     */
    
    public function fetch()
    {
        // массив для хранения строк выборки
        $resultList = array();
        // ключ для формирование строки
        $i          = 0;

        // если ресурс запроса пуст
        if ($this->resourceQuery === FALSE)
            // выводим false
            return FALSE;
        
        // +1 к кол-ву select запросов сделанных системой RS-MINI
        self::$selectCount++;
        
        // листаем строки выбокри
        while ($row = mysqli_fetch_assoc($this->resourceQuery)) {
            // листаем поля строки
            foreach ($row as $key => $value)
                // заполняем массив
                $resultList[$i][$key] = $value;
            
            // переключаем строку
            $i++;
        }
        
        // если выборка пустая
        if (empty($resultList)) {
            // пытаемся получить ошибку
            $error = mysqli_error(self::$resource);
            
            // если нет ошибок, то селект запрос просто вернул 0 строк
            if (empty($error))
                // вертаем false
                return FALSE;
            
            // если ошибка есть, то показываем ее на экран
            echo $error;
            
            // закрываем подключение
            self::close();
            
            // убиваем скрипт
            die();
        }
        
        // возвращаем выборку
        return $resultList;
    }
    
    /*
     * метод закрывает подключение к БД
     * 
     * @access - public
     * @return - true или false
     * 
     */
    
    public static function close()
    {
        return mysqli_close(self::$resource);
    }
}
